==> rn-hidoop-ui-lib-0.1.10.tgz: package/src/Components/Molecules/Card/StoreMedium.js <==
import React from 'react';
import { Image, StyleSheet, TouchableOpacity, View } from 'react-native';
import { colors, width } from '../../../constant/theme';
import { Icon, Text } from '../../Atoms';
import { ButtonText } from '../Button';

const StoreMedium = ({ data = {}, onCardPress, style }) => {
  return (
    <TouchableOpacity
      onPress={onCardPress}
      key={data?.id?.toString()}
      style={[styles.cardWrapper, styles.shadow, style]}
    >
      <View style={styles.imageWrapper}>
        <Image
          source={data?.image}
          resizeMode="cover"
          resizeMethod="auto"
          style={styles.imageThumbnail}
        />
      </View>
      <View style={styles.distanceWrapper}>
        <Icon name="location" color={colors.primary} size={15} />
        <Text
          text={data?.distance?.toString() + ' km'}
          variant="light"
          textStyle={{ marginLeft: width * 0.01 }}
        />
      </View>
      <Text
        text={data?.name}
        variant="bold"
        textStyle={styles.cardTitle}
        size="large"
      />
      <Text text={data?.address} textStyle={styles.cardTitle} />
      <View style={styles.distanceWrapper}>
        <ButtonText title={'Buka'} />
      </View>
    </TouchableOpacity>
  );
};

const styles = StyleSheet.create({
  shadow: {
    elevation: 3,
    shadowColor: colors.grey.grey4,
    shadowOffset: { width: 0, height: 0 },
    shadowRadius: 10,
    shadowOpacity: 0.1,
  },
  cardWrapper: {
    backgroundColor: 'white',
    width: '43%',
    borderRadius: 20,
    padding: width * 0.03,
    margin: width * 0.03,
  },
  imageWrapper: {
    width: '100%',
    height: width * 0.345,
    marginBottom: width * 0.03,
  },
  imageThumbnail: {
    width: '100%',
    height: '100%',
    aspectRatio: 1,
    borderRadius: 20,
  },
  distanceWrapper: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    width: '100%',
  },
  cardTitle: {
    marginLeft: width * 0.01,
    width: '100%',
    textAlign: 'center',
    marginVertical: width * 0.03,
  },
});

export default StoreMedium;

==> rn-hidoop-ui-lib-0.1.11.tgz: package/src/Components/Molecules/Card/StoreMedium.js <==
import React from 'react';
import { Image, StyleSheet, TouchableOpacity, View } from 'react-native';
import { colors, width } from '../../../constant/theme';
import { Icon, Text } from '../../Atoms';
import { ButtonText } from '../Button';

const StoreMedium = ({ data = {}, onCardPress, style, imageStyle }) => {
  return (
    <TouchableOpacity
      onPress={onCardPress}
      key={data?.id?.toString()}
      style={[styles.cardWrapper, styles.shadow, style]}
    >
      <View style={[styles.imageWrapper, imageStyle]}>
        <Image
          source={data?.image}
          resizeMode="cover"
          resizeMethod="auto"
          style={styles.imageThumbnail}
        />
      </View>
      <View style={styles.distanceWrapper}>
        <Icon name="location" color={colors.primary} size={15} />
        <Text
          text={data?.distance?.toString() + ' km'}
          variant="light"
          textStyle={{ marginLeft: width * 0.01 }}
        />
      </View>
      <Text
        text={data?.name}
        variant="bold"
        textStyle={styles.cardTitle}
        size="large"
      />
      <Text text={data?.address} textStyle={styles.cardTitle} />
      <View style={styles.distanceWrapper}>
        <ButtonText title={'Buka'} />
      </View>
    </TouchableOpacity>
  );
};

const styles = StyleSheet.create({
  shadow: {
    elevation: 3,
    shadowColor: colors.grey.grey4,
    shadowOffset: { width: 0, height: 0 },
    shadowRadius: 10,
    shadowOpacity: 0.1,
  },
  cardWrapper: {
    backgroundColor: 'white',
    width: '43%',
    borderRadius: 20,
    padding: width * 0.03,
    margin: width * 0.03,
  },
  imageWrapper: {
    width: '100%',
    height: width * 0.345,
    marginBottom: width * 0.03,
  },
  imageThumbnail: {
    width: '100%',
    height: '100%',
    aspectRatio: 1,
    borderRadius: 20,
  },
  distanceWrapper: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    width: '100%',
  },
  cardTitle: {
    marginLeft: width * 0.01,
    width: '100%',
    textAlign: 'center',
    marginVertical: width * 0.03,
  },
});

export default StoreMedium;
